@@ -23,13 +23,13 @@ build_time_vars = {'ABIFLAGS': '',
            '-ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
            '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
            '-ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
            '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1',
+           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -38,38 +38,39 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '-ggdb -O2 -pipe -Wall -Werror=format-security '
                      '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                      '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1',
+                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12' "
+ 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16' "
                 "'--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' "
                 "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python38' "
                 "'--htmldir=/usr/share/doc/python38/html' '-C' "
                 "'--enable-shared' '--enable-ipv6' '--with-libc=' "
                 "'--with-libm=' '--with-system-expat' '--with-system-ffi' "
-                "'--without-ensurepip' "
+                "'--without-ensurepip' '--enable-loadable-sqlite-extensions' "
                 "'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' "
                 "'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security "
                 '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                 '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-                "-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1' "
+                '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+                "-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1' "
                 "'LDFLAGS=' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pub/devel/python/python38/python38-3.8.12-1.x86_64/build/coverage.info',
- 'COVERAGE_REPORT': '/pub/devel/python/python38/python38-3.8.12-1.x86_64/build/lcov-report',
+ 'COVERAGE_INFO': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/build/coverage.info',
+ 'COVERAGE_REPORT': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include',
+             '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib /usr/lib/python3.8 /usr/lib/python3.8/lib-dynload',
  'DESTLIB': '/usr/lib/python3.8',
@@ -313,7 +314,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 0,
- 'HAVE_MEMORY_H': 1,
+ 'HAVE_MEMORY_H': 0,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
@@ -581,8 +582,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Modules/makesetup',
+ 'MAJOR_IN_SYSMACROS': 1,
+ 'MAKESETUP': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -648,58 +649,60 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fstack-protector-strong '
                              '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
                              '-ggdb -O2 -pipe -Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                              '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration  '
-                             '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include/internal '
+                             '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include '
+                             '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-ggdb -O2 -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
               '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
               '-ggdb -O2 -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
               '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1',
+              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration  '
-                     '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include/internal',
+                     '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                    '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
                    '-ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                    '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration  '
-                   '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include/internal '
+                   '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include '
+                   '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include',
+                '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
@@ -710,19 +713,20 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
                         '-DOPENSSL_NO_SSL3=1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
                         '-ggdb -O2 -pipe -Wall -Werror=format-security '
                         '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                         '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/build=/usr/src/debug/python38-3.8.12-1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12=/usr/src/debug/python38-3.8.12-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
                         '-std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration  '
-                        '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include/internal '
+                        '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Include',
+                        '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -761,7 +765,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-38-x86_64-cygwin',
  'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -776,7 +780,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python.exe '
-               '/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Tools/scripts/run_tests.py',
+               '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -784,10 +788,10 @@ build_time_vars = {'ABIFLAGS': '',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.8 '
-                '/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12/Tools/scripts/update_file.py',
+                '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.8',
- 'VPATH': '/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12',
+ 'VPATH': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -799,9 +803,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pub/devel/python/python38/python38-3.8.12-1.x86_64/build',
- 'abs_srcdir': '/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12',
+ 'abs_builddir': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/build',
+ 'abs_srcdir': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/pub/devel/python/python38/python38-3.8.12-1.x86_64/src/Python-3.8.12'}
+ 'srcdir': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16'}
